---
title: "Great Blogposts"
listing:
  type: table
  sort: "date desc"
  feed: true
  contents:
    - "**.qmd"
    #- title: "Title"
    #  author: "Authors"
    #  date: 20XX-01-01
    #  path: url
---

